import { s as r, c as s, a as e, C as t } from "./chunk-YQZZRAKN-BQvCB-Ut.js";
import { _ as l } from "./mermaid.core-BiIw1_mh.js";
var d = {
  parser: e,
  get db() {
    return new t();
  },
  renderer: s,
  styles: r,
  init: /* @__PURE__ */ l((a) => {
    a.class || (a.class = {}), a.class.arrowMarkerAbsolute = a.arrowMarkerAbsolute;
  }, "init")
};
export {
  d as diagram
};
