import { _ as l } from "./mermaid.core-BiIw1_mh.js";
function m(e, c) {
  var i, t, o;
  e.accDescr && ((i = c.setAccDescription) == null || i.call(c, e.accDescr)), e.accTitle && ((t = c.setAccTitle) == null || t.call(c, e.accTitle)), e.title && ((o = c.setDiagramTitle) == null || o.call(c, e.title));
}
l(m, "populateCommonDb");
export {
  m as p
};
